@@ -3,15 +3,15 @@
 # license that can be found in the LICENSE file.
 
 import json
-import os
 import re
 import requests
 
 
 def extract_message(msg):
-    regex = "\d+\-\d+\-\d+ \d+\:\d+\:\d+ \[\d+\] \[\w+\] " #like 2012-11-06 18:30:10 [13887] [INFO]
+    # 2012-11-06 18:30:10 [13887] [INFO]
+    regex = "\d+\-\d+\-\d+ \d+\:\d+\:\d+ \[\d+\] \[\w+\] "
     msgs = re.split(regex, msg)
-    return [msg for msg in msgs if msg] #removing empty entries
+    return [m for m in msgs if m]
 
 
 class Stream(object):
