@@ -17,6 +17,10 @@ NOPATH_OUTPUT = {
 }
 
 
+def remove_env(name):
+    del os.environ[name]
+
+
 def create_fake_call(status_return, options_return=NOPATH_OUTPUT):
     kw = []
 
@@ -42,8 +46,6 @@ class ApprcWatcherTest(unittest.TestCase):
         self.assertEqual(expected, kw)
 
     def test_add_envs_may_override_os_environ(self):
-        def remove_env(name):
-            del os.environ[name]
         os.environ["SOMETHING_UNKNOWN"] = "123"
         self.addCleanup(remove_env, "SOMETHING_UNKNOWN")
         plugin = ApprcWatcher("", "", 1)
@@ -56,7 +58,6 @@ class ApprcWatcherTest(unittest.TestCase):
         self.assertEqual(expected, kw)
 
     def test_add_envs_dont_call_set_when_variables_dont_change(self):
-        self.maxDiff = None
         plugin = ApprcWatcher("", "", 1)
         envs = copy.deepcopy(NOPATH_OUTPUT)
         envs["options"]["env"].update(os.environ)
@@ -65,7 +66,6 @@ class ApprcWatcherTest(unittest.TestCase):
         self.assertEqual([], kw)
 
     def test_add_envs_dont_call_set_when_variables_dont_change_and_ses_os_environ(self):
-        self.maxDiff = None
         plugin = ApprcWatcher("", "", 1)
         envs = copy.deepcopy(NOPATH_OUTPUT)
         envs["options"]["env"].update(os.environ)
@@ -73,6 +73,39 @@ class ApprcWatcherTest(unittest.TestCase):
         plugin.add_envs(name="name", envs=envs["options"]["env"])
         self.assertEqual([], kw)
 
+    def test_add_envs_override_environs(self):
+        plugin = ApprcWatcher("", "", 1)
+        envs = copy.deepcopy(NOPATH_OUTPUT)
+        envs["options"]["env"]["foo"] = "foo"
+        plugin.call, kw = create_fake_call(None, envs)
+        plugin.add_envs(name="name", envs={"foo": "bar"})
+        env = copy.deepcopy(os.environ)
+        env["foo"] = "bar"
+        expected = [{"name": "name", "options": {"env": env}}]
+        self.assertEqual(expected, kw)
+
+    def test_add_env_ignores_PYTHONPATH_from_os_environ(self):
+        os.environ["PYTHONPATH"] = "/home/user/python"
+        self.addCleanup(remove_env, "PYTHONPATH")
+        plugin = ApprcWatcher("", "", 1)
+        plugin.call, kw = create_fake_call(None)
+        plugin.add_envs(name="name", envs={"foo": "bar"})
+        env = copy.deepcopy(os.environ)
+        env["foo"] = "bar"
+        del env["PYTHONPATH"]
+        expected = [{"name": "name", "options": {"env": env}}]
+        self.assertEqual(expected, kw)
+
+    def test_add_env_doesnt_ignore_PYTHONPATH_from_apprc(self):
+        plugin = ApprcWatcher("", "", 1)
+        plugin.call, kw = create_fake_call(None)
+        plugin.add_envs(name="name", envs={"foo": "bar", "PYTHONPATH": "/usr/lib/python"})
+        env = copy.deepcopy(os.environ)
+        env["foo"] = "bar"
+        env["PYTHONPATH"] = "/usr/lib/python"
+        expected = [{"name": "name", "options": {"env": env}}]
+        self.assertEqual(expected, kw)
+
     def test_look_after_add_envs(self):
         sr = {"statuses": {"name": "name", "cmd": "cmd"}}
         fake_call, kw = create_fake_call(sr)
